@@ -301,10 +301,6 @@ class ip:
            print(get.text)
     def proxy(data=False):
         import requests
-        infinity = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-        infi_ip = infinity["ip"]
-        infi_port = infinity["port"]
-        proxis = infi_ip+":"+infi_port
         if data:
            proxy = []
            proxy.append(proxis)
@@ -333,13 +329,6 @@ class ip:
            t.start()
            time.sleep(2)
            done = True
-           print("\nIp         : "+infi_ip)
-           print("Port       : "+infi_port)
-           print("Https      : True")
-           print("Google     : True")
-           print("Country    : Randomized")
-           print("Checked    : Infinite")
-           print("Anonymity  : Tor\n")
            proxy_list = pyproxify.fetch(count=3, google=True, https=True)
            for item in proxy_list:
               ip = item["ip"]
@@ -357,7 +346,7 @@ class ip:
               print("Anonymity  : "+anonymity)
               print(" ")
            proxy_list = pyproxify.fetch(count=2, google=False, https=True)
-           for item in proxy_list:
+           for item in proxy_list:9
               ip = item["ip"]
               port = item["port"]
               last = item["last_update"]
@@ -465,13 +454,13 @@ class inquiry:
                  timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-                     ip = p["ip"]
-                     port = p["port"]
+                     ip = p["socksip"]
+                     port = p["socksport"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
-                     proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
+                     proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
                      with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
@@ -575,13 +564,13 @@ class inquiry:
                  timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-                     ip = p["ip"]
-                     port = p["port"]
+                     ip = p["socksip"]
+                     port = p["socksport"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
-                     proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
+                     proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
                      with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
@@ -664,13 +653,13 @@ class inquiry:
                  timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-                     ip = p["ip"]
-                     port = p["port"]
+                     ip = p["socksip"]
+                     port = p["socksport"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
-                     proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
+                     proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
                      with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
@@ -753,13 +742,13 @@ class inquiry:
                  timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-                     ip = p["ip"]
-                     port = p["port"]
+                     ip = p["socksip"]
+                     port = p["socksport"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
-                     proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
+                     proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
                      with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
@@ -842,13 +831,13 @@ class inquiry:
                  timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-                     ip = p["ip"]
-                     port = p["port"]
+                     ip = p["socksip"]
+                     port = p["socksport"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
-                     proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
+                     proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
                      with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
